### R code from vignette source 'cr_6.Rnw'

###################################################
### code chunk number 1: cr_6.Rnw:29-32
###################################################
plot(e, n, cex=Clay5*3/max(Clay5), pch=20, col=as.numeric(zone), asp=1)
grid(lty=1)  
title("Postplot of topsoil clay %, by soil type")


###################################################
### code chunk number 2: cr_6.Rnw:115-116
###################################################
while (is.element("package:spatial", search())) detach(package:spatial)


###################################################
### code chunk number 3: cr_6.Rnw:119-123
###################################################
require(spatial)
clay5.ls<-surf.ls(1, e, n, Clay5)
summary(clay5.ls)
clay5.ls$beta


###################################################
### code chunk number 4: cr_6.Rnw:135-139
###################################################
(predict(clay5.ls,
     diff(range(e))/2 + min(e),
     diff(range(n))/2 + min(n)))
clay5.ls$beta[1]


###################################################
### code chunk number 5: cr_6.Rnw:181-186
###################################################
c <- correlogram(clay5.ls, 50, plotit=F)
str(c)
plot(c, ylim=c(-.2, .6), xlim=c(0,12000), pch=20, col="blue")
text(c$x, c$y, round(c$y, 2), pos=3)
abline(h=0)


###################################################
### code chunk number 6: cr_6.Rnw:216-221
###################################################
                    # estimate function by eye: exponential
plot(c, ylim=c(-.2, .6), xlim=c(0,12000), pch=20, col="blue")
abline(h=0)
d <- seq(100,12000, by=100)
lines(d, expcov(d, d=600, alpha=.4), col="blue")


###################################################
### code chunk number 7: cr_6.Rnw:224-225
###################################################
rm(c, d)


###################################################
### code chunk number 8: cr_6.Rnw:230-235
###################################################
# fits fairly well at close range
                    # now fit the GLS surface
clay5.gls<-surf.gls(1, expcov, d=600, alpha=.4, e, n, Clay5)
summary(clay5.gls)
clay5.gls$beta


###################################################
### code chunk number 9: cr_6.Rnw:251-252
###################################################
while (is.element("package:lattice", search())) detach(package:lattice)


###################################################
### code chunk number 10: cr_6.Rnw:255-256
###################################################
require(lattice)


###################################################
### code chunk number 11: cr_6.Rnw:263-273
###################################################
xmin <- min(e); xmax <- max(e); ymin <- min(n); ymax <- max(n); res <- 40
clay5.ts <- trmat(clay5.ls, xmin, xmax, ymin, ymax, res)
clay5.gts <- trmat(clay5.gls, xmin, xmax, ymin, ymax, res)
eqscplot(clay5.gts, type="n",
     main="OLS and GLS trend surfaces, subsoil clay %", xlab="E", ylab="N")
contour(clay5.gts, level=seq(20, 80, 4), add=T)
contour(clay5.ts, level=seq(20, 80, 4), add=T, lty=2, col="blue")
grid(lty=1)
points(e, n, cex=Clay5*2.5/max(Clay5), pch=23, bg=3)
rm(clay5.ts, clay5.gts, xmin, xmax, ymin, ymax, res)


###################################################
### code chunk number 12: cr_6.Rnw:291-304
###################################################
xmin <- min(e); xmax <- max(e); ymin <- min(n); ymax <- max(n); res <- 40
clay5.gls <- surf.gls(1, expcov, d=600, alpha=.4, e, n, Clay5)
clay5.gls.resid <- resid(clay5.gls)
clay5.gts <- trmat(clay5.gls, xmin, xmax, ymin, ymax, res)
eqscplot(clay5.gts, type="n",
     main="Residuals from GLS 1st-order trend surface, subsoil clay %",
     sub="Red: negative; Green: positive",
     xlab="E", ylab="N")
contour(clay5.gts, level=seq(20, 80, 4), add=T)
grid(lty=1)
points(e, n, cex=abs(clay5.gls.resid)*2.5/max(abs(clay5.gls.resid)),
       pch=23, bg=ifelse(clay5.gls.resid < 0, 3, 2))
rm(clay5.gls, clay5.gts, clay5.gls.resid, xmin, xmax, ymin, ymax, res)


###################################################
### code chunk number 13: cr_6.Rnw:338-349
###################################################
xmin <- min(e); xmax <- max(e); ymin <- min(n); ymax <- max(n); res <- 40
clay5.gls2 <- surf.gls(2, expcov, d=600, alpha=.4, e, n, Clay5)
summary(clay5.gls2)
clay5.gts2 <- trmat(clay5.gls2, xmin, xmax, ymin, ymax, res)
eqscplot(clay5.gts2, type="n",
     main="GLS 2nd-order trend surface, subsoil clay %", xlab="E", ylab="N")
contour(clay5.gts2, level=seq(20, 80, 4), add=T)
grid(lty=1)
points(e, n, cex=Clay5*2.5/max(Clay5), pch=23, bg=3)
clay5.gls2$beta
rm(clay5.gls2, clay5.gts2, xmin, xmax, ymin, ymax, res)


###################################################
### code chunk number 14: cr_6.Rnw:381-383
###################################################
while (is.element("package:gstat", search())) detach(package:gstat)
while (is.element("package:sp", search())) detach(package:sp)


###################################################
### code chunk number 15: cr_6.Rnw:386-389
###################################################
require(sp)
require(gstat)
search()


###################################################
### code chunk number 16: cr_6.Rnw:399-400
###################################################
str(obs)


###################################################
### code chunk number 17: cr_6.Rnw:421-425
###################################################
class(obs)
obs.sp <- obs
coordinates(obs.sp) <- ~ e + n
class(obs.sp)


###################################################
### code chunk number 18: cr_6.Rnw:441-444
###################################################
str(obs.sp)
head(obs.sp@data)
summary(obs.sp@data)


###################################################
### code chunk number 19: cr_6.Rnw:460-462
###################################################
v <- variogram(Clay5 ~ 1, obs.sp)
print(plot(v, pl=T, pch=20, col="blue", cex=1.5))


###################################################
### code chunk number 20: cr_6.Rnw:492-494
###################################################
m <- vgm(100, "Exp", 15000/3, 50)
print(plot(v, pl=T, pch=20, col="blue", cex=1.5, model=m))


###################################################
### code chunk number 21: cr_6.Rnw:504-508
###################################################
(m.f <- fit.variogram(v, m))
str(m.f)
attr(m.f, "SSErr")
print(plot(v, pl=T, pch=20, col="blue", cex=1.5, model=m.f))


###################################################
### code chunk number 22: cr_6.Rnw:540-543
###################################################
diff(range(e))/1000
diff(range(n))/1000
diff(range(e)) * diff(range(n)) / 10^6


###################################################
### code chunk number 23: cr_6.Rnw:550-556
###################################################
res <- 500
g500 <- expand.grid(e = seq(min(e), max(e), by=res), n = seq(min(n), max(n), by=res))
coordinates(g500) <- ~ e + n
gridded(g500) <- T
str(g500)
rm(res)


###################################################
### code chunk number 24: cr_6.Rnw:562-564
###################################################
k.o <- krige(Clay5 ~ 1, obs.sp, g500, m.f)
str(k.o)


###################################################
### code chunk number 25: cr_6.Rnw:576-584
###################################################
plot.1 <- spplot(k.o, zcol="var1.pred",
   main="OK prediction of Clay %, 30-50 cm", col.regions=bpy.colors(128),
                 pretty=T)
plot.2 <- spplot(k.o, zcol="var1.var",
   main="OK prediction variance of Clay %, 30-50 cm", col.regions=cm.colors(128),
                 pretty=T)
print(plot.1, split=c(1,1,2,1), more=T)
print(plot.2, split=c(2,1,2,1), more=F)


###################################################
### code chunk number 26: cr_6.Rnw:624-628
###################################################
k.o.500 <- krige(Clay5 ~ 1, obs.sp, g500, m.f, block=c(500, 500))
str(k.o.500)
summary(k.o$var1.pred - k.o.500$var1.pred)
summary(k.o.500$var1.var / k.o$var1.var)


